MODULE chemparam_mod

!MODULE qui definit les indices des traceurs et leurs masses molaires.
! utilise aussi pour variables communes nuages/photochimie

IMPLICIT NONE

!----------------------------------------------------------------------------  
INTEGER, SAVE :: i_co2, i_co, i_h2, i_h2o, i_o1d,        &
                 i_o, i_o2, i_o2dg, i_o3, i_h,           &
                 i_oh, i_ho2, i_h2o2, i_cl, i_clo,       &
                 i_cl2, i_hcl, i_hocl, i_clco, i_clco3,  &
                 i_cocl2, i_s, i_so, i_so2, i_so3,       &
                 i_s2o2, i_ocs, i_hso3, i_h2so4, i_s2,   &
                 i_clso2, i_oscl, i_n2, i_he, i_n, i_no, &
                 i_no2, i_n2d,                           &
                 i_co2plus, i_coplus, i_oplus, i_o2plus, &
                 i_n2plus, i_hplus, i_h2oplus, i_nplus,  &
                 i_ohplus, i_cplus, i_noplus, i_h3oplus, & 
                 i_hcoplus, i_hco2plus, i_elec     
                 
INTEGER, SAVE :: i_h2oliq, i_h2so4liq

INTEGER, SAVE :: i_m0_aer, i_m3_aer,                       &
                 i_m0_mode1drop, i_m0_mode1ccn,            &
		 i_m3_mode1sa, i_m3_mode1w, i_m3_mode1ccn, &
		 i_m0_mode2drop, i_m0_mode2ccn,            &
		 i_m3_mode2sa, i_m3_mode2w, i_m3_mode2ccn

INTEGER, SAVE :: nmicro  ! number of microphysical tracers 

REAL, DIMENSION(:), SAVE, ALLOCATABLE :: M_tr     ! Molecular Mass of tracers
REAL, DIMENSION(:), SAVE, ALLOCATABLE :: type_tr  ! type of tracer 
 
REAL, DIMENSION(:,:),SAVE, ALLOCATABLE :: no_emission
REAL, DIMENSION(:,:),SAVE, ALLOCATABLE :: o2_emission 
!----------------------------------------------------------------------------
! DEF FOR CL_SCHEME = 1 (AURELIEN)

!     number of clouds mode modelized
      INTEGER, PARAMETER :: nbr_mode = 3
      INTEGER :: i_cloud
      INTEGER, SAVE :: cloudmax
      INTEGER, SAVE :: cloudmin
      REAL, SAVE, DIMENSION(:,:,:), ALLOCATABLE :: R_MEDIAN
      REAL, SAVE, DIMENSION(:,:,:), ALLOCATABLE :: STDDEV
      
!     K_MASS coefficient correspondant à la partie condensee de chaque mode
      REAL, SAVE, DIMENSION(:,:,:), ALLOCATABLE :: K_MASS

      REAL, SAVE, DIMENSION(:,:,:), ALLOCATABLE :: NBRTOT
      REAL, SAVE, DIMENSION(:,:), ALLOCATABLE :: WH2SO4
      REAL, SAVE, DIMENSION(:,:), ALLOCATABLE :: rho_droplet
!----------------------------------------------------------------------------
! DEF FOR CL_SCHEME = 2 (FULL MICROPHYS)

!----------------------------------------------------------------------------

!---------------------------------------------------------------------------- 
  CONTAINS
!----------------------------------------------------------------------------

  SUBROUTINE cloud_ini(nbr_lon,nbr_lev)

!=============================================================
!	cloud_ini definit le champ 3D des caracteristiques du nuage
  
      INTEGER :: nbr_lon,nbr_lev,i_lev
    
      ALLOCATE(NBRTOT(nbr_lon,nbr_lev,nbr_mode))
      ALLOCATE(R_MEDIAN(nbr_lon,nbr_lev,nbr_mode))
      ALLOCATE(K_MASS(nbr_lon,nbr_lev,nbr_mode))
      ALLOCATE(STDDEV(nbr_lon,nbr_lev,nbr_mode))
      ALLOCATE(WH2SO4(nbr_lon,nbr_lev))
      ALLOCATE(rho_droplet(nbr_lon,nbr_lev))
            
      PRINT*,'=========================='
      PRINT*,'Initialisation cloud layer'
      PRINT*,'=========================='
      PRINT*,'nbr_lon',nbr_lon
      PRINT*,'nbr_lev',nbr_lev
      PRINT*,'nbr_mode',nbr_mode
	
      NBRTOT(:,:,:)    = 0.0E+0
      WH2SO4(:,:)      = 0.0E+0
      rho_droplet(:,:) = 0.0E+0
            
!=============================================================
!		      Initialisation cloud layer 1
!=============================================================
!     cloudmin et cloudmax niveaux du GCM
      cloudmin= 18
      cloudmax= 50

!     radius R_MEDIAN en m (donc *e-6 pour microns)
	
	R_MEDIAN(:,:,:)=0.0E+0		 ! Geometric Average Radius
	STDDEV(:,:,:)=0.0E+0             ! Geometric Std Deviation
	K_MASS(:,:,:)=0.0E+0             ! Coeff multimodal

!	===============================================
!	Knollenberg & Hunten, 1980 and James et al 1997
!	===============================================

!	===============================================
!	Initialisation UNIMODALE
!	===============================================

!     Lower Haze: mode 1
!      DO i_lev=cloudmin,20
!      R_MEDIAN(:,i_lev,1)=0.2e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.56
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!     Lower Cloud: mode 3
!      DO i_lev=21,23
!      R_MEDIAN(:,i_lev,1)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!     Middle Cloud: mode 2 prime
!      DO i_lev=24,28
!      R_MEDIAN(:,i_lev,1)=1.4e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.23
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!     Upper Cloud: mode 2
!      DO i_lev=29,35
!      R_MEDIAN(:,i_lev,1)=1.0e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.29
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!     Upper Haze: mode 1
!      DO i_lev=36, cloudmax
!      R_MEDIAN(:,i_lev,1)=0.2e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=2.16
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!	===============================================
!	Initialisation TRIMODALE
!	===============================================

!     Lower Haze: mode 1
!      DO i_lev=cloudmin,20
!      R_MEDIAN(:,i_lev,1)=0.3e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.56
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO
                              
!     Lower Haze: mode 2
!      DO i_lev=cloudmin,20
!      R_MEDIAN(:,i_lev,2)=1.4e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.23
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO

!     Lower Haze: mode 3
!      DO i_lev=cloudmin,20
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO  

!     Lower Cloud: mode 1
!      DO i_lev=21,23
!      R_MEDIAN(:,i_lev,1)=0.3e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.56
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=0.1
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO
                              
!     Lower Cloud: mode 2 prime
!      DO i_lev=21,23
!      R_MEDIAN(:,i_lev,2)=1.4e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.23
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.4
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO

!     Lower Cloud: mode 3
!      DO i_lev=21,23
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.5
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO 

!     Middle Cloud: mode 1
!      DO i_lev=24,28
!      R_MEDIAN(:,i_lev,1)=0.3e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.56
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO
         
!     Middle Cloud: mode 2 prime
!      DO i_lev=24,28
!      R_MEDIAN(:,i_lev,2)=1.4e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.23
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.8
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO
   
!     Middle Cloud: mode 3
!      DO i_lev=24,28
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.2
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO


!     Upper Cloud: mode 1
!      DO i_lev=29,35
!      R_MEDIAN(:,i_lev,1)=0.3e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.56
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=0.15
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!     Upper Cloud: mode 2
!      DO i_lev=29,35
!      R_MEDIAN(:,i_lev,2)=1.0e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.29
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.85
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO
        
!     Upper Cloud: mode 3
!      DO i_lev=29,35
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO

!     Upper Haze: mode 1
!      DO i_lev=36, cloudmax
!      R_MEDIAN(:,i_lev,1)=0.3e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.56
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!     Upper Haze: mode 2
!      DO i_lev=36, cloudmax
!      R_MEDIAN(:,i_lev,2)=1.e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.29
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO
      
!     Upper Haze: mode 3
!      DO i_lev=36, cloudmax
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=2.16
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO       
!=============================================================

!	===============================================
!	Initialisation TRIMODALE Knollenberg 
!	===============================================

!     Lower Haze: mode 1
      DO i_lev=cloudmin,22
      R_MEDIAN(:,i_lev,1)=0.1e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
      STDDEV(:,i_lev,1)=1.57
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
      K_MASS(:,i_lev,1)=1.0
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
      END DO
                              
!     Lower Haze: mode 2
      DO i_lev=cloudmin,22
      R_MEDIAN(:,i_lev,2)=1.4e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
      STDDEV(:,i_lev,2)=1.23
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
      K_MASS(:,i_lev,2)=0.0
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
      END DO

!     Lower Haze: mode 3
      DO i_lev=cloudmin,22
      R_MEDIAN(:,i_lev,3)=3.65e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
      STDDEV(:,i_lev,3)=1.28
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
      K_MASS(:,i_lev,3)=0.0
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
      END DO  

!     Pre Cloud: mode 1
      DO i_lev=23,23
      R_MEDIAN(:,i_lev,1)=0.15e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
      STDDEV(:,i_lev,1)=1.8
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
      K_MASS(:,i_lev,1)=0.04
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
      END DO
                              
!     Pre Cloud: mode 2
      DO i_lev=23,23
      R_MEDIAN(:,i_lev,2)=1.0e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
      STDDEV(:,i_lev,2)=1.29
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
      K_MASS(:,i_lev,2)=0.96
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
      END DO

!     Pre Cloud: mode 3
      DO i_lev=23,23
      R_MEDIAN(:,i_lev,3)=3.65e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
      STDDEV(:,i_lev,3)=1.28
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
      K_MASS(:,i_lev,3)=0.0
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
      END DO 
                  
!      Lower Cloud: mode 1
      DO i_lev=24,24
      R_MEDIAN(:,i_lev,1)=0.2e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
      STDDEV(:,i_lev,1)=1.8
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
      K_MASS(:,i_lev,1)=0.014
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
      END DO
         	
!     Lower Cloud: mode 2
      DO i_lev=24,24
      R_MEDIAN(:,i_lev,2)=1.0e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
      STDDEV(:,i_lev,2)=1.29
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
      K_MASS(:,i_lev,2)=0.02
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
      END DO

!     Lower Cloud: mode 3
      DO i_lev=24,24
      R_MEDIAN(:,i_lev,3)=3.65e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
      STDDEV(:,i_lev,3)=1.28
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
      K_MASS(:,i_lev,3)=0.966
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
      END DO

!     Middle Cloud: mode 1
      DO i_lev=25,28
      R_MEDIAN(:,i_lev,1)=0.15e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
      STDDEV(:,i_lev,1)=1.9
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
      K_MASS(:,i_lev,1)=0.0084
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
      END DO
         
!     Middle Cloud: mode 2 prime
      DO i_lev=25,28
      R_MEDIAN(:,i_lev,2)=1.4e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
      STDDEV(:,i_lev,2)=1.23
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
      K_MASS(:,i_lev,2)=0.21
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
      END DO
   
!     Middle Cloud: mode 3
      DO i_lev=25,28
      R_MEDIAN(:,i_lev,3)=3.65e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
      STDDEV(:,i_lev,3)=1.28
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
      K_MASS(:,i_lev,3)=0.7816
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
      END DO

!      option: upper haze remplacee par extension upper cloud
!         => 35 remplace par cloudmax et upper haze commentee
!	===============================================

!     Upper Cloud: mode 1
      DO i_lev=29,35 !cloudmax
      R_MEDIAN(:,i_lev,1)=0.2e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
      STDDEV(:,i_lev,1)=2.16
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
      K_MASS(:,i_lev,1)=0.72
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
      END DO

!     Upper Cloud: mode 2
      DO i_lev=29,35 !cloudmax
      R_MEDIAN(:,i_lev,2)=1.0e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
      STDDEV(:,i_lev,2)=1.29
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
      K_MASS(:,i_lev,2)=0.28
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
      END DO
        
!     Upper Cloud: mode 3
      DO i_lev=29,35 !cloudmax
      R_MEDIAN(:,i_lev,3)=3.65e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
      STDDEV(:,i_lev,3)=1.28
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
      K_MASS(:,i_lev,3)=0.0
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
      END DO

!     Upper Haze: mode 1
      DO i_lev=36, cloudmax
      R_MEDIAN(:,i_lev,1)=0.2e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
      STDDEV(:,i_lev,1)=2.16
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
      K_MASS(:,i_lev,1)=1.0
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
      END DO

!     Upper Haze: mode 2
      DO i_lev=36, cloudmax
      R_MEDIAN(:,i_lev,2)=1.e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
      STDDEV(:,i_lev,2)=1.29
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
      K_MASS(:,i_lev,2)=0.0
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
      END DO
      
!     Upper Haze: mode 3
      DO i_lev=36, cloudmax
      R_MEDIAN(:,i_lev,3)=3.65e-6
      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
      STDDEV(:,i_lev,3)=2.16
      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
      K_MASS(:,i_lev,3)=0.0
      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
      END DO       

!=============================================================

!	===============================================================
!	Initialisation TRIMODALE "Knollenberg" sans Mode3, Mode2 etendu
!	===============================================================

!     Lower Haze: mode 1
!      DO i_lev=cloudmin,22
!      R_MEDIAN(:,i_lev,1)=0.1e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.57
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO
                              
!     Lower Haze: mode 2
!      DO i_lev=cloudmin,22
!      R_MEDIAN(:,i_lev,2)=1.4e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.23
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO

!     Lower Haze: mode 3
!      DO i_lev=cloudmin,22
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO  

!     Pre Cloud: mode 1
!      DO i_lev=23,23
!      R_MEDIAN(:,i_lev,1)=0.15e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.8
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=0.04
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO
                              
!     Pre Cloud: mode 2
!      DO i_lev=23,23
!      R_MEDIAN(:,i_lev,2)=1.0e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.29
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.96
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO

!     Pre Cloud: mode 3
!      DO i_lev=23,23
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO 
                  
!      Lower Cloud: mode 1
!      DO i_lev=24,24
!      R_MEDIAN(:,i_lev,1)=0.2e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.8
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=0.014
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO
         	
!     Lower Cloud: mode 2
!      DO i_lev=24,24
!      R_MEDIAN(:,i_lev,2)=1.0e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.6
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.986
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO

!     Lower Cloud: mode 3
!      DO i_lev=24,24
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO

!     Middle Cloud: mode 1
!      DO i_lev=25,28
!      R_MEDIAN(:,i_lev,1)=0.15e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=1.9
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=0.0084
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO
         
!     Middle Cloud: mode 2 prime
!      DO i_lev=25,28
!      R_MEDIAN(:,i_lev,2)=1.4e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.6
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.9916 
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO
   
!     Middle Cloud: mode 3
!      DO i_lev=25,28
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO


!     Upper Cloud: mode 1
!      DO i_lev=29,35
!      R_MEDIAN(:,i_lev,1)=0.2e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=2.16
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=0.72
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!     Upper Cloud: mode 2
!      DO i_lev=29,35
!      R_MEDIAN(:,i_lev,2)=1.0e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.29
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.28
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO
        
!     Upper Cloud: mode 3
!      DO i_lev=29,35
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=1.28
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO

!     Upper Haze: mode 1
!      DO i_lev=36, cloudmax
!      R_MEDIAN(:,i_lev,1)=0.2e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,1)
!      STDDEV(:,i_lev,1)=2.16
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,1)
!      K_MASS(:,i_lev,1)=1.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,1)
!      END DO

!     Upper Haze: mode 2
!      DO i_lev=36, cloudmax
!      R_MEDIAN(:,i_lev,2)=1.e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,2)
!      STDDEV(:,i_lev,2)=1.29
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,2)
!      K_MASS(:,i_lev,2)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,2)
!      END DO
      
!     Upper Haze: mode 3
!      DO i_lev=36, cloudmax
!      R_MEDIAN(:,i_lev,3)=3.65e-6
!      PRINT*,'level',i_lev,'R R_MEDIAN',R_MEDIAN(1,i_lev,3)
!      STDDEV(:,i_lev,3)=2.16
!      PRINT*,'level',i_lev,'Dev Std',STDDEV(1,i_lev,3)
!      K_MASS(:,i_lev,3)=0.0
!      PRINT*,'level',i_lev,'Coeff Mass: k_mass',K_MASS(1,i_lev,3)
!      END DO       

!=============================================================
      PRINT*,'==============================='
      PRINT*,'FIN Initialisation cloud layer'
      PRINT*,'==============================='
      
  END SUBROUTINE cloud_ini
  
! ===========================================================

  SUBROUTINE chemparam_ini
  USE infotrac_phy, ONLY: nqtot, tname
  IMPLICIT NONE
  INTEGER :: i
  
  ALLOCATE(M_tr(nqtot))    ! Molecular Mass of Chemistry Tracers
  ALLOCATE(type_tr(nqtot)) ! Type of chemistry tracers 1: neutral, 2: ion, 3: liquide

! Initialisation index chemistry tracers

  ! Neutral gas Tracer
  i_co2      = 0
  i_co       = 0
  i_h2       = 0
  i_h2o      = 0
  i_o1d      = 0
  i_o        = 0
  i_o2       = 0
  i_o2dg     = 0
  i_o3       = 0
  i_h        = 0
  i_oh       = 0
  i_ho2      = 0
  i_h2o2     = 0
  i_cl       = 0
  i_clo      = 0
  i_cl2      = 0
  i_hcl      = 0
  i_hocl     = 0
  i_clco     = 0
  i_clco3    = 0
  i_cocl2    = 0
  i_s        = 0
  i_so       = 0
  i_so2      = 0
  i_so3      = 0
  i_s2o2     = 0
  i_ocs      = 0
  i_hso3     = 0
  i_h2so4    = 0
  i_s2       = 0
  i_clso2    = 0
  i_oscl     = 0
  i_n2       = 0
  i_he       = 0 
  i_n2d      = 0
  i_n        = 0
  i_no       = 0
  i_no2      = 0
  ! ION TRACERS FOR IONCHEM = TRUE
  i_co2plus  = 0 
  i_coplus   = 0
  i_oplus    = 0 
  i_o2plus   = 0
  i_n2plus   = 0 
  i_hplus    = 0 
  i_h2oplus  = 0 
  i_nplus    = 0
  i_ohplus   = 0 
  i_cplus    = 0 
  i_noplus   = 0 
  i_h3oplus  = 0
  i_hcoplus  = 0 
  i_hco2plus = 0
  i_elec     = 0  
  ! MICROPHYSICAL TRACERS FOR CL_SCHEME=1
  i_h2oliq   = 0
  i_h2so4liq = 0  

  DO i=1, nqtot                                 
	
	PRINT*,'i',i
	PRINT*,'tname(i)',tname(i)
	
  	SELECT CASE(tname(i))
! NEUTRAL TRACERS
  		CASE('co2')
  		i_co2=i
  		PRINT*,'co2',i_co2
  		M_tr(i_co2) = 44.0095
      type_tr(i_co2) = 1  
  		CASE('co')
  		i_co=i
  		PRINT*,'co',i_co
  		M_tr(i_co)=28.0101
      type_tr(i_co) = 1 
  		CASE('h2')
  		i_h2=i
  		PRINT*,'h2',i_h2
  		M_tr(i_h2)= 2.01588
      type_tr(i_h2) = 1 
  		CASE('h2o')
  		i_h2o=i
  		PRINT*,'h2o',i_h2o
  		M_tr(i_h2o)=18.0153
      type_tr(i_h2o) = 1 
  		CASE('o1d')
  		i_o1d=i
  		PRINT*,'o1d',i_o1d
  		M_tr(i_o1d)=15.994
      type_tr(i_o1d) = 1 
  		CASE('o')
  		i_o=i
  		PRINT*,'o',i_o
  		M_tr(i_o)=15.994
      type_tr(i_o) = 1 
  		CASE('o2')
  		i_o2=i
  		PRINT*,'o2',i_o2
  		M_tr(i_o2)=31.9988
      type_tr(i_o2) = 1 
  		CASE('o2dg')
  		i_o2dg=i
  		PRINT*,'o2dg',i_o2dg
  		M_tr(i_o2dg)=31.9988
      type_tr(i_o2dg) = 1
  		CASE('o3')
  		i_o3=i
  		PRINT*,'o3',i_o3
  		M_tr(i_o3)= 47.9982
      type_tr(i_o3) = 1 
  		CASE('h')
  		i_h=i
  		PRINT*,'h',i_h
  		M_tr(i_h)= 1.00794
      type_tr(i_h) = 1  
  		CASE('oh')
  		i_oh=i
  		PRINT*,'oh',i_oh
  		M_tr(i_oh)=17.0073
      type_tr(i_oh) = 1
  		CASE('ho2')
  		i_ho2=i
  		PRINT*,'ho2',i_ho2
  		M_tr(i_ho2)=33.0067
      type_tr(i_ho2) = 1
  		CASE('h2o2')
  		i_h2o2=i
  		PRINT*,'h2o2',i_h2o2
  		M_tr(i_h2o2)=34.0147
      type_tr(i_h2o2) = 1 
  		CASE('cl')
  		i_cl=i
  		PRINT*,'cl',i_cl
  		M_tr(i_cl)=35.453
      type_tr(i_cl) = 1
  		CASE('clo')
  		i_clo=i
  		PRINT*,'clo',i_clo
  		M_tr(i_clo)=51.452
      type_tr(i_clo) = 1
  		CASE('cl2')
  		i_cl2=i
  		PRINT*,'cl2',i_cl2
  		M_tr(i_cl2)=70.906
      type_tr(i_cl2) = 1
  		CASE('hcl')
  		i_hcl=i
  		PRINT*,'hcl',i_hcl
  		M_tr(i_hcl)=36.461
      type_tr(i_hcl) = 1
  		CASE('hocl')
  		i_hocl=i
  		PRINT*,'hocl',i_hocl
  		M_tr(i_hocl)=52.46
  		type_tr(i_hocl) = 1
      CASE('clco')
  		i_clco=i
  		PRINT*,'clco',i_clco
  		M_tr(i_clco)=63.463
  		type_tr(i_clco) = 1
      CASE('clco3')
  		i_clco3=i
  		PRINT*,'clco3',i_clco3
  		M_tr(i_clco3)=95.462 
  		type_tr(i_clco3) = 1
      CASE('cocl2')
  		i_cocl2=i
  		PRINT*,'cocl2',i_cocl2
  		M_tr(i_cocl2)=98.916
  		type_tr(i_cocl2) = 1
      CASE('s')
  		i_s=i
  		PRINT*,'s',i_s
  		M_tr(i_s)=32.065
  		type_tr(i_s) = 1
      CASE('so')
  		i_so=i
  		PRINT*,'so',i_so
  		M_tr(i_so)=48.0644
  		type_tr(i_so) = 1
      CASE('so2')
  		i_so2=i
  		PRINT*,'so2',i_so2
  		M_tr(i_so2)=64.064 
  		type_tr(i_so2) = 1
      CASE('so3')
  		i_so3=i
  		PRINT*,'so3',i_so3
  		M_tr(i_so3)=80.063
  		type_tr(i_so3) = 1
      CASE('s2o2')
  		i_s2o2=i
  		PRINT*,'s2o2',i_s2o2
  		M_tr(i_s2o2)= 96.1288 
  		type_tr(i_s2o2) = 1
      CASE('ocs')
  		i_ocs=i
  		PRINT*,'ocs',i_ocs
  		M_tr(i_ocs)=60.0751
  		type_tr(i_ocs) = 1
      CASE('hso3')
  		i_hso3=i
  		PRINT*,'hso3',i_hso3
  		M_tr(i_hso3)=81.071
  		type_tr(i_hso3) = 1
      CASE('h2so4')
  		i_h2so4=i
  		PRINT*,'h2so4',i_h2so4
  		M_tr(i_h2so4)=98.078
  		type_tr(i_h2so4) = 1
      CASE('s2')
  		i_s2=i
  		PRINT*,'s2',i_s2
  		M_tr(i_s2)=64.13
  		type_tr(i_s2) = 1
      CASE('clso2')
  		i_clso2=i
  		PRINT*,'clso2',i_clso2
  		M_tr(i_clso2)=99.517
  		type_tr(i_clso2) = 1
      CASE('oscl')
  		i_oscl=i
  		PRINT*,'oscl',i_oscl
  		M_tr(i_oscl)=83.517
		  type_tr(i_oscl) = 1
      CASE('n2')
		  i_n2=i
      PRINT*,'n2',i_n2
		  M_tr(i_n2)=28.013
		  type_tr(i_n2) = 1
      CASE('he')
		  i_he=i
      PRINT*,'he',i_he
		  M_tr(i_he)=4.0026
		  type_tr(i_he) = 1
      CASE('n2d')
		  i_n2d=i
      PRINT*,'n2d',i_n2d
		  M_tr(i_n2d)=14.0067
		  type_tr(i_n2d) = 1
      CASE('n')
		  i_n=i
      PRINT*,'n',i_n
		  M_tr(i_n)=14.0067
		  type_tr(i_n) = 1
      CASE('no')
		  i_no=i
      PRINT*,'no',i_no
		  M_tr(i_no)=30.0061   
		  type_tr(i_no) = 1
      CASE('no2')
		  i_no2=i
      PRINT*,'no2',i_no2
		  M_tr(i_no2)=46.0055
      type_tr(i_no2) = 1          
! ION TRACERS FOR OK_IONCHEM = TRUE
      CASE('co2plus')
      i_co2plus=i
      PRINT*,'co2plus',i_co2plus
      M_tr(i_co2plus)=44.0095 
      type_tr(i_co2plus) = 2
      CASE('coplus')
      i_coplus=i
      PRINT*,'coplus',i_coplus
      M_tr(i_coplus)=28.0101 
      type_tr(i_coplus) = 2
      CASE('oplus')
      i_oplus=i
      PRINT*,'oplus',i_oplus
      M_tr(i_oplus)=15.994
      type_tr(i_oplus) = 2
      CASE('o2plus')
      i_o2plus=i
      PRINT*,'o2plus',i_o2plus
      M_tr(i_o2plus)=31.9988
      type_tr(i_o2plus) = 2
      CASE('n2plus')
      i_n2plus=i
      PRINT*,'n2plus',i_n2plus
      M_tr(i_n2plus)=28.013
      type_tr(i_n2plus) = 2
      CASE('hplus')
      i_hplus=i
      PRINT*,'hplus',i_hplus
      M_tr(i_hplus)=1.00794
		  type_tr(i_hplus) = 2
      CASE('h2oplus')
      i_h2oplus=i
      PRINT*,'h2oplus',i_h2oplus
      M_tr(i_h2oplus)=18.0153
		  type_tr(i_h2oplus) = 2      
      CASE('nplus')
		  i_nplus=i
      PRINT*,'nplus',i_nplus
		  M_tr(i_nplus)=14.0067
		  type_tr(i_nplus) = 2
      CASE('ohplus')
		  i_ohplus=i
      PRINT*,'ohplus',i_ohplus
		  M_tr(i_ohplus)=17.0073
		  type_tr(i_ohplus) = 2
      CASE('cplus')
		  i_cplus=i
      PRINT*,'cplus',i_cplus
		  M_tr(i_cplus)=12.011
		  type_tr(i_cplus) = 2
      CASE('noplus')
		  i_noplus=i
      PRINT*,'noplus',i_noplus
		  M_tr(i_noplus)=30.0061
		  type_tr(i_noplus) = 2
      CASE('h3oplus')
		  i_h3oplus=i
      PRINT*,'h3oplus',i_h3oplus
		  M_tr(i_h3oplus)=19.0232
		  type_tr(i_h3oplus) = 2
      CASE('hcoplus')
		  i_hcoplus=i
      PRINT*,'hcoplus',i_hcoplus
		  M_tr(i_hcoplus)=29.0180
		  type_tr(i_hcoplus) = 2
      CASE('hco2plus')
		  i_hco2plus=i
      PRINT*,'hco2plus',i_hco2plus
		  M_tr(i_hco2plus)=45.
 		  type_tr(i_hco2plus) = 2
      CASE('elec')
		  i_elec=i
      PRINT*,'elec',i_elec
		  M_tr(i_elec)=1./1822.89
      type_tr(i_elec) = 2       
! MICROPHYSICAL TRACERS FOR CL_SCHEME=1
  		CASE('h2oliq')
  		i_h2oliq=i
  		PRINT*,'h2oliq',i_h2oliq
  		M_tr(i_h2oliq)=18.0153
      type_tr(i_h2oliq) = 3
  		CASE('h2so4liq')
  		i_h2so4liq=i
  		PRINT*,'h2so4liq',i_h2so4liq
  		M_tr(i_h2so4liq)=98.078
      type_tr(i_h2so4liq) = 3
! MICROPHYSICAL TRACERS FOR CL_SCHEME=2
    CASE('M0_aer')
		i_m0_aer=i
    type_tr(i_m0_aer) = 10
		PRINT*,'M0_aer',i_m0_aer
		CASE('M3_aer')
		i_m3_aer=i
    type_tr(i_m3_aer) = 10
		PRINT*,'M3_aer',i_m3_aer
    CASE('M0_m1drop')
		i_m0_mode1drop=i
    type_tr(i_m0_mode1drop) = 10
		PRINT*,'M0_m1drop',i_m0_mode1drop
    CASE('M0_m1ccn')
		i_m0_mode1ccn=i
    type_tr(i_m0_mode1ccn) = 10
		PRINT*,'M0_m1ccn',i_m0_mode1ccn
		CASE('M3_m1sa')
		i_m3_mode1sa=i
    type_tr(i_m3_mode1sa) = 10
		PRINT*,'M3_m1sa',i_m3_mode1sa
		CASE('M3_m1w')
		i_m3_mode1w=i
    type_tr(i_m3_mode1w) = 10
		PRINT*,'M3_m1w',i_m3_mode1w
		CASE('M3_m1ccn')
		i_m3_mode1ccn=i
    type_tr(i_m3_mode1ccn) = 10
		PRINT*,'M3_m1ccn',i_m3_mode1ccn
    CASE('M0_m2drop')
		i_m0_mode2drop=i
    type_tr(i_m0_mode2drop) = 10
		PRINT*,'M0_m2drop',i_m0_mode2drop
    CASE('M0_m2ccn')
		i_m0_mode2ccn=i
    type_tr(i_m0_mode2ccn) = 10
		PRINT*,'M0_m2ccn',i_m0_mode2ccn
		CASE('M3_m2sa')
		i_m3_mode2sa=i
    type_tr(i_m3_mode2sa) = 10
		PRINT*,'M3_m2sa',i_m3_mode2sa
		CASE('M3_m2w')
		i_m3_mode2w=i
    type_tr(i_m3_mode2w) = 10
		PRINT*,'M3_m2w',i_m3_mode2w
		CASE('M3_m2ccn')
		i_m3_mode2ccn=i
    type_tr(i_m3_mode2ccn) = 10
		PRINT*,'M3_m2ccn',i_m3_mode2ccn
  	END SELECT
  	
!  	PRINT*,'M_tr(i)',M_tr(i)
  END DO
  
  END SUBROUTINE chemparam_ini

! ===========================================================

  SUBROUTINE vapors4muphy_ini(nlon,nlev,trac)
  USE infotrac_phy, ONLY: nqtot, tname
  IMPLICIT NONE

  integer :: nlon, nlev
  real    :: trac(nlon,nlev,nqtot) ! traceur ( en vmr)

!  integer :: i
!  real    :: trac1d(nlev,2) ! traceur lu ( en vmr)
 
! lecture d'un fichier texte contenant les profils de trac1d(:1) = H2O et trac1d(:,2) = H2SO4
!  DO i=1,nlon
!     trac(i,:,i_h2o) = trac1d(:,1)
!     trac(i,:,i_h2so4) = trac1d(:,2)
!  ENDDO

!  intitialisation profils altitude H2O et H2SO4
!  profil H2O initial vap+liq == que vap
   trac(:,1:24,i_h2o) = 30.E-6 !
   trac(:,25:50,i_h2o) = 1.E-6 !

   trac(:,:,i_h2so4) = 3.E-9 ! Limite sup Sandor 2012
   trac(:,23:50,i_h2so4) = 2.E-6 ! Profil H2SO4 initial => vap+liq

  END SUBROUTINE vapors4muphy_ini

END MODULE chemparam_mod

